/**
 *
 * Ce programme montre comment il est possible d'utiliser le clavier.
 * Pour cela, le programme utilise la fonction :
 *
 *------------------------------------------------------------------------------
 * MLV_keyboard_wait : Suspend l'exécution jusqu'à ce que l'utilisateur
 *                     appuie sur une touche du clavier.
 *                     Lorsque l'utilisateur appuie sur une touche, la 
 *                     fonction retourne trois valeurs ( sym, mod et unicode )
 *                     correspondant respectivement au code de la touche, au
 *                     mode dans lequel se trouve le clavier (majuscule etc ...)
 *                     et au caractère unicode obtenu en combinant le mode du
 *                     clavier et le code de la touche appuyée.
 *
 *                     La fonction accepte des valeurs nulles pour les 
 *                     pointeurs sym, mod et unicode.
 *                     Dans ce cas la fonction ignore les champs en question.
 *
 * void MLV_keyboard_wait(
 *     int*        sym,        Code de la touche 
 *     int*        mod,        Mode dans lequel se trouve le clavier
 *     int*        unicode     Caractère codé en unicode de la lettre obtenu
 *                             en combinant le code et le mode de la touche
 * );
 *
 *------------------------------------------------------------------------------
 * Il est possible d'obtenir la liste exaustive des :
 *    - différents codes associées aux différentes touches
 *    - différents modes
 * en consultant respectivement les énumerations 
 *    - MLV_Keyboard
 *    - MLV_Keyboard_mod 
 * du fichier MLV_keyboard.h  ( faire un man MLV_keyboard.h )
 *
 * Pour consulter la documentation du fichier MLV_keyboard.h vous pouvez
 * taper dans le terminal la commande :
 * man MLV_keyboard.h
 *
 */

#include <MLV_all.h>

//
// Programme principal
//
// Attention ! 
// Pour pouvoir compiler ce programme sous windows et sous macintosh,
// il faut, pour la déclaration du main, respecter strictement la syntaxe
// suivante :
//
int main(int argc, char *argv[]){
	//
	// Déclaration de la variable qui représentera le code de la touche qui
	// sera appuyée par l'utilisateur.
	//
	int touche;

	//
	// Créé et affiche la fenêtre
	//
	MLV_create_window( "Nom_fenetre", "nom_icone", 640, 480 );

	//
	// Affiche la consigne
	//
	MLV_draw_text( 10, 10, "Appuyez sur la touche k", MLV_COLOR_GREEN );
	MLV_actualise_window();

	//
	// Attendre que l'utilisateur appuie sur une touche du clavier
	//
	MLV_keyboard_wait( &touche, NULL, NULL );

	//
	// Affiche "Bien !" si l'utilisateur a appuyer sur la touche k sinon
	// affiche un message d'erreur.
	//
	if( touche == MLV_KEYBOARD_k ){
		MLV_draw_text( 10, 30, "Bien !", MLV_COLOR_GREEN );
	}else{
		MLV_draw_text( 
			10, 30, "Vous n'avez pas appuyé sur la touche k",
			MLV_COLOR_GREEN
		);
	}
	MLV_actualise_window();
	
	//
	// Attend 2 seconde avant la fin du programme.
	//
	MLV_wait_seconds( 2 );
	
	//
	// Ferme la fenêtre
	//
	MLV_close_window();
	return 0;
}
